@@ -455,7 +455,7 @@ sub run {
     my $changes = $group->get_changes_processable;
     tag 'source-only-upload-to-non-free-without-autobuild'
       if defined($changes)
-      and $changes->info->field('architecture', 'source')
+      and $changes->info->field('architecture', '') eq 'source'
       and $info->is_non_free
       and $info->source_field('xs-autobuild', 'no') eq 'no';
 
