@@ -439,23 +439,20 @@ sub process_tasks {
                         # failed ...
                         $failed{$procid} = 1;
                         delete $active{$procid};
-                        return;
+                    }else {
+                        # The collection was success
+                        $lpkg->_mark_coll_finished($coll, $cs->version);
+                        $cmap->satisfy($coll);
+                       # If the entry is marked as failed, don't break the loop
+                       # for it.
+                        return if exists $failed{$procid};
+                        $active{$procid} = 1 if $cmap->selectable;
                     }
 
-                    # The collection was success
-                    $lpkg->_mark_coll_finished($coll, $cs->version);
-                    $cmap->satisfy($coll);
-                    # If the entry is marked as failed, don't break the loop
-                    # for it.
-                    return if exists $failed{$procid};
-                    $active{$procid} = 1 if $cmap->selectable;
-                    while (1) {
-                        my @task = $find_next_task->();
-                        last if not @task;
-                        $sch_task_inner->(@task);
-                        last
-                          if $jobs and scalar(keys(%{$running_jobs})) >= $jobs;
-                    }
+                    my @task = $find_next_task->();
+                    $sch_task_inner->(@task)
+                      if @task;
+
                     $loop->loop_stop if not %{$running_jobs};
                     if ($debug_enabled) {
                         my $queue = join(', ', sort(values(%{$running_jobs})));
@@ -473,11 +470,11 @@ sub process_tasks {
         #$loop->add($process);
     };
 
-    while (1) {
+    for (0..$jobs-1) {
         my @task = $find_next_task->();
         last if not @task;
-        $schedule_task->(@task);
-        last if $jobs and scalar(keys(%{$running_jobs})) >= $jobs;
+        $schedule_task->(@task)
+          or last;
     }
 
     $loop->run;
